declare module "*"

import { IGatsbyImageData } from "gatsby-plugin-image"

interface LayoutProps {
    children: React.ReactNode
    UserMenu?: React.ReactNode
}

/**
 * Default Layout with Header (Helmet & SEO) and Footer
 * @param {LayoutProps} props - Page content
 * @returns {JSX.Element} The complete page
 */
export function Layout(props: LayoutProps): JSX.Element

interface ContentProps {
    children: React.ReactNode
    className?: string
}

/**
 * Centered section for page content
 * @param {ContentProps} props - Section content
 * @returns {JSX.Element} The complete section
 */
export function Content(props: ContentProps): JSX.Element

interface ButtonProps {
    children?: React.ReactNode
    name?: string
    url?: string
    className?: string
}
export function Button(props: ButtonProps): JSX.Element

interface CardProps {
    name?: string
    description?: string
    image?: string
    url?: string
    anime?: boolean
    layout?: "top" | "left"
    className?: string
    size?: "xs" | "base" | "xl" 
}
export function Card(props: CardProps): JSX.Element
interface Icookies {
    location?: string
    buttonText?: string
    declineButtonText?: String
    expires?: number
    styles?: {}
    buttonStyles?: {}
    declineButtonStyle?: {}
    decline: any
}
export function Cookies(props: Icookies): JSX.Element

interface BadgeProps {
    children?: React.ReactNode
    title?: string
    className?: string
}
export function Badge(props: BadgeProps): JSX.Element

interface TocProps {
    children?: React.ReactNode
    className?: string
}
export function Toc(props: TocProps): JSX.Element
interface FooterProps {
    className?: string
}
export function Footer(props: FooterProps): JSX.Element

interface Iheader {
    className?: string
    logo?: any
}
export function Header(props: Iheader): JSX.Element

interface LinkProps {
    children?: React.ReactNode
    to: string
    activeClassName?: string
    partiallyActive?: string
    onClick?: any
    className?: any
}
export function Link(props: LinkProps): JSX.Element

interface Istats {
    children?: React.ReactNode
    className?: string
    icon?: JSX.Element
    title?: string
    value?: string
    description?: string
    iconColor?: string
    valueColor?: string
    descriptionColor?: string
}
export function Stats(props: Istats): JSX.Element

interface DataImage {
    src: string
}
interface ICarousel {
    images: Array<DataImage>
    isLogo: boolean
    delay?: number
    fullSize?: boolean
}
export function Carousel(props: ICarousel): JSX.Element

interface SearchProps {}
export function Search(props: SearchProps): JSX.Element

interface ISocials {
    logo?: any
    name?: string
    url?: string
    // className?: string,
    layout?: string
    // dataList: any
}
export function Socials(props: ISocials): JSX.Element

interface IMenu {
    classname?: string
    name?: string
}
export function Menu(props: IMenu): JSX.Element

interface IMenuMobile {}
export function MenuMobile(props: IMenu): JSX.Element

interface Ilogo {
    to?: string
    src?: string
    title: string
    image?: any
    className?: string
}
export function Logo(props: Ilogo): JSX.Element

interface PartnersProps {
    className?: string
    delay?: number
}
export function Partners(props: PartnersProps): JSX.Element

interface Service {
    name: string
    description: string
    image: string
    url: string
}
interface Action {
    name: string
    url: string
}
interface HeroProps {
    title?: string
    subtitle?: string
    content?: string
    action: Action
    services?: Array<Service>
}

/**
 * Hero section with background image and buttons action
 * @param {HeroProps} props - Section content
 * @returns {JSX.Element} The complete section
 */
export function Hero(props: HeroProps): JSX.Element

interface MapProps {
  mapid: number;
}
export function Map(props: MapProps): JSX.Element

interface FeatureProps {
    title?: string
    content?: string
    image?: string | IGatsbyImageData
    mapid?: number
    layout?: "left" | "right"
    backgroundImage?: string
    action?: {
        name?: string
        url?: string
        className?: string
    }
    custom?: JSX.Element
}
export function Feature(props: FeatureProps): JSX.Element
interface Iimage {
    image?: string | IGatsbyImageData
    className?: string
}
export function Image(props: Iimage): JSX.Element
interface CardListProps {
    cards?: CardProps[]
    layout?: "row" | "col" | "grid"
    className?: string
    anime?: boolean
}
export function CardList(props: CardListProps): JSX.Element;
interface INews {
    title?: string
    action?: {
        name?: string
        url?: string
        classname?: string
    }
    anime?: boolean
}
export function News(props: INews): JSX.Element

declare module "@onegeo/gatsby-theme-onegeo"
