import React, { ReactElement, useState } from "react";
import { graphql, PageProps } from "gatsby";
import { IGatsbyImageData } from "gatsby-plugin-image";

import Layout from "../layouts/layout";
import CardList from "../components/core/CardList";

interface INew {
  id?: string;
  title?: string;
  content?: string;
  image?: {
    id?: string;
    imageFile?: IGatsbyImageData;
  };
}

interface DataProps {
  directus: {
    news: INew[];
  };
}

const IconListRow = () => {
  return (
    <svg
      xmlns="http://www.w3.org/2000/svg"
      fill="none"
      viewBox="0 0 24 24"
      strokeWidth="1.5"
      stroke="currentColor"
      className="w-8 h-8"
    >
      <path
        strokeLinecap="round"
        strokeLinejoin="round"
        d="M8.25 6.75h12M8.25 12h12m-12 5.25h12M3.75 6.75h.007v.008H3.75V6.75zm.375 0a.375.375 0 11-.75 0 .375.375 0 01.75 0zM3.75 12h.007v.008H3.75V12zm.375 0a.375.375 0 11-.75 0 .375.375 0 01.75 0zm-.375 5.25h.007v.008H3.75v-.008zm.375 0a.375.375 0 11-.75 0 .375.375 0 01.75 0z"
      />
    </svg>
  );
};

const IconListGrid = () => {
  return (
    <svg
      xmlns="http://www.w3.org/2000/svg"
      fill="none"
      viewBox="0 0 24 24"
      strokeWidth="1.5"
      stroke="currentColor"
      className="w-8 h-8"
    >
      <path
        strokeLinecap="round"
        strokeLinejoin="round"
        d="M3.75 6A2.25 2.25 0 016 3.75h2.25A2.25 2.25 0 0110.5 6v2.25a2.25 2.25 0 01-2.25 2.25H6a2.25 2.25 0 01-2.25-2.25V6zM3.75 15.75A2.25 2.25 0 016 13.5h2.25a2.25 2.25 0 012.25 2.25V18a2.25 2.25 0 01-2.25 2.25H6A2.25 2.25 0 013.75 18v-2.25zM13.5 6a2.25 2.25 0 012.25-2.25H18A2.25 2.25 0 0120.25 6v2.25A2.25 2.25 0 0118 10.5h-2.25a2.25 2.25 0 01-2.25-2.25V6zM13.5 15.75a2.25 2.25 0 012.25-2.25H18a2.25 2.25 0 012.25 2.25V18A2.25 2.25 0 0118 20.25h-2.25A2.25 2.25 0 0113.5 18v-2.25z"
      />
    </svg>
  );
};

function News({ data }: PageProps<DataProps>): ReactElement {
  const [bLayoutGrid, setLayoutGrid] = useState(false);

  const onSetLayout = () => {
    setLayoutGrid((prevState) => !prevState);
  };

  const layout = bLayoutGrid ? "grid" : "row";

  const listNews = data.directus.news.map((dt) => {
    return {
      title: dt.title,
      content: dt.content,
      image: dt.image?.imageFile,
    };
  });

  return (
    <Layout>
      <div className="max-w-7xl mx-auto px-2 sm:px-4 lg:px-8 my-4">
        <div className="sm:flex sm:justify-between sm:items-center sm:gap-12">
          <h2 className="mt-2 text-3xl font-extrabold tracking-tight sm:text-4xl mb-8  w-full">
            Actualités
          </h2>
          <div className="flex justify-between items-center space-x-10 w-full">
            <button
              className="h-10 w-10 flex justify-center items-center"
              onClick={onSetLayout}
            >
              {bLayoutGrid ? <IconListGrid /> : <IconListRow />}
            </button>
            <input
              type="text"
              placeholder="Titre, description"
              className="input input-bordered w-full"
            />
          </div>
        </div>
        <div className="mt-4">
          <CardList cards={listNews} layout={layout} anime={bLayoutGrid} />
        </div>
      </div>
    </Layout>
  );
}

export default News;

export const query = graphql`
  query {
    directus {
      news(
        filter: { status: { _eq: "published" } }
        sort: "-date_published"
      ) {
        id
        content
        title
        date_published
        image {
          id
          imageFile {
            childImageSharp {
              gatsbyImageData
            }
          }
        }
      }
    }
  }
`;
